# lapidarist

[![CI](https://github.com/The-AI-Alliance/lapidarist/actions/workflows/pytest.yml/badge.svg)](https://github.com/The-AI-Alliance/lapidarist/actions/workflows/pytest.yml)
[![PyPI](https://img.shields.io/pypi/v/lapidarist)](https://pypi.org/project/lapidarist/)
[![License](https://img.shields.io/github/license/The-AI-Alliance/lapidarist)](https://github.com/The-AI-Alliance/lapidarist/tree/main?tab=Apache-2.0-1-ov-file#readme)
[![Issues](https://img.shields.io/github/issues/The-AI-Alliance/lapidarist)](https://github.com/The-AI-Alliance/lapidarist/issues)
[![GitHub stars](https://img.shields.io/github/stars/The-AI-Alliance/lapidarist?style=social)](https://github.com/The-AI-Alliance/lapidarist/stargazers)

lapidarist is a small library for using LLMs to create
various kinds of indices and data structures used by AI Agents.

See the [website](https://the-ai-alliance.github.io/lapidarist/) for quickstart info, goals, and other links.

To find the lapidarist community, see the [discussions](https://github.com/The-AI-Alliance/lapidarist/discussions)
